Page MenuHomePhabricator

D8747.diff
No OneTemporary

D8747.diff

diff --git a/src/util/system.cpp b/src/util/system.cpp
--- a/src/util/system.cpp
+++ b/src/util/system.cpp
@@ -1296,14 +1296,14 @@
}
#endif
// On most POSIX systems (e.g. Linux, but not BSD) the environment's locale may
// be invalid, in which case the "C" locale is used as fallback.
#if !defined(WIN32) && !defined(MAC_OSX) && !defined(__FreeBSD__) && \
!defined(__OpenBSD__)
try {
// Raises a runtime error if current locale is invalid.
std::locale("");
} catch (const std::runtime_error &) {
- setenv("LC_ALL", "C", 1);
+ setenv("LC_ALL", "C.UTF-8", 1);
}
#elif defined(WIN32)
// Set the default input/output charset is utf-8
@@ -1296,14 +1296,14 @@
#endif
// On most POSIX systems (e.g. Linux, but not BSD) the environment's locale may
-// be invalid, in which case the "C" locale is used as fallback.
+// be invalid, in which case the "C.UTF-8" locale is used as fallback.
#if !defined(WIN32) && !defined(MAC_OSX) && !defined(__FreeBSD__) && \
!defined(__OpenBSD__)

File Metadata

Mime Type
text/plain
Expires
Sat, Mar 1, 12:08 (25 m, 57 s)
Storage Engine
blob
Storage Format
Raw Data
Storage Handle
5187782
Default Alt Text
D8747.diff (780 B)

Event Timeline